Documentation
¶
Index ¶
- Constants
- Variables
- type ProbeConf
- func (*ProbeConf) Descriptor() ([]byte, []int)deprecated
- func (x *ProbeConf) GetDisableIntegrityCheck() bool
- func (x *ProbeConf) GetPacketsIntervalMsec() int32
- func (x *ProbeConf) GetPacketsPerProbe() int32
- func (x *ProbeConf) GetPayloadSize() int32
- func (x *ProbeConf) GetResolveTargetsInterval() int32
- func (x *ProbeConf) GetUseDatagramSocket() bool
- func (*ProbeConf) ProtoMessage()
- func (x *ProbeConf) ProtoReflect() protoreflect.Message
- func (x *ProbeConf) Reset()
- func (x *ProbeConf) String() string
Constants ¶
const ( Default_ProbeConf_PacketsPerProbe = int32(2) Default_ProbeConf_PacketsIntervalMsec = int32(25) Default_ProbeConf_ResolveTargetsInterval = int32(5) Default_ProbeConf_PayloadSize = int32(56) Default_ProbeConf_UseDatagramSocket = bool(true) Default_ProbeConf_DisableIntegrityCheck = bool(false) )
Default values for ProbeConf fields.
Variables ¶
var File_github_com_google_cloudprober_probes_ping_proto_config_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ProbeConf ¶
type ProbeConf struct {
// Packets per probe
PacketsPerProbe *int32 `protobuf:"varint,6,opt,name=packets_per_probe,json=packetsPerProbe,def=2" json:"packets_per_probe,omitempty"`
// How long to wait between two packets to the same target
PacketsIntervalMsec *int32 `protobuf:"varint,7,opt,name=packets_interval_msec,json=packetsIntervalMsec,def=25" json:"packets_interval_msec,omitempty"`
// Resolve targets after these many probes
ResolveTargetsInterval *int32 `` // =10s
/* 129-byte string literal not displayed */
// Ping payload size in bytes. It cannot be smaller than 8, number of bytes
// required for the nanoseconds timestamp.
PayloadSize *int32 `protobuf:"varint,10,opt,name=payload_size,json=payloadSize,def=56" json:"payload_size,omitempty"`
// Use datagram socket for ICMP.
// This option enables unprivileged pings (that is, you don't require root
// privilege to send ICMP packets). Note that most of the Linux distributions
// don't allow unprivileged pings by default. To enable unprivileged pings on
// some Linux distributions, you may need to run the following command:
// sudo sysctl -w net.ipv4.ping_group_range="0 <large valid group id>"
// net.ipv4.ping_group_range system setting takes two integers that specify
// the group id range that is allowed to execute the unprivileged pings. Note
// that the same setting (with ipv4 in the path) applies to IPv6 as well.
UseDatagramSocket *bool `protobuf:"varint,12,opt,name=use_datagram_socket,json=useDatagramSocket,def=1" json:"use_datagram_socket,omitempty"`
// Disable integrity checks. To detect data courruption in the network, we
// craft the outgoing ICMP packet payload in a certain format and verify that
// the reply payload matches the same format.
DisableIntegrityCheck *bool `` /* 127-byte string literal not displayed */
// contains filtered or unexported fields
}
Next tag: 1
func (*ProbeConf) Descriptor
deprecated
func (*ProbeConf) GetDisableIntegrityCheck ¶
func (*ProbeConf) GetPacketsIntervalMsec ¶
func (*ProbeConf) GetPacketsPerProbe ¶
func (*ProbeConf) GetPayloadSize ¶
func (*ProbeConf) GetResolveTargetsInterval ¶
func (*ProbeConf) GetUseDatagramSocket ¶
func (*ProbeConf) ProtoMessage ¶
func (*ProbeConf) ProtoMessage()
func (*ProbeConf) ProtoReflect ¶ added in v0.10.8
func (x *ProbeConf) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.